==============
django-newauth
==============

See the docs at: http://django-newauth.rtfd.io/

Run tests using tox::

    $ tox


Links
=====

- `PyPI <https://pypi.python.org/pypi/django-newauth>`__
- `Documentation <http://django-newauth.rtfd.io/>`__
- `Repository <https://github.com/beproud/django-newauth/>`__

LICENSE
=======

BSD License.

